pub enum FieldFilterOp {
Eq,
Ne,
Gt,
Lt,
Gte,
Lte,
Contains,
StartsWith,
}Expand description
Operator for comparing a feature attribute to a FilterValue.
Variants
Eq
Equal to.
Ne
Not equal to.
Gt
Greater than (numeric comparison).
Lt
Less than (numeric comparison).
Gte
Greater than or equal to (numeric comparison).
Lte
Less than or equal to (numeric comparison).
Contains
String contains the value as a substring (string types only).
StartsWith
String starts with the value as a prefix (string types only).